@@ -51,9 +51,11 @@ typedef struct
 {
 	TotemPlugin   parent;
 	TotemObject  *totem;
+	BaconVideoWidget *bvw;
 
 	TotemScrsaver *scr;
 	guint          handler_id_playing;
+	guint          handler_id_metadata;
 	guint          handler_id_gconf;
 } TotemScreensaverPlugin;
 
@@ -66,7 +68,6 @@ typedef struct
 G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
 GType	totem_screensaver_plugin_get_type		(void) G_GNUC_CONST;
 
-static void totem_screensaver_plugin_init		(TotemScreensaverPlugin *plugin);
 static void totem_screensaver_plugin_finalize		(GObject *object);
 static gboolean impl_activate				(TotemPlugin *plugin, TotemObject *totem, GError **error);
 static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
@@ -120,7 +121,9 @@ totem_screensaver_update_from_state (TotemObject *totem,
 							   NULL);
 	can_get_frames = bacon_video_widget_can_get_frames (bvw, NULL);
 
-	if (totem_is_playing (totem) != FALSE && (lock_screensaver_on_audio || can_get_frames))
+	if (totem_is_playing (totem) != FALSE && can_get_frames)
+		totem_scrsaver_disable (pi->scr);
+	else if (totem_is_playing (totem) != FALSE && !lock_screensaver_on_audio)
 		totem_scrsaver_disable (pi->scr);
 	else
 		totem_scrsaver_enable (pi->scr);
@@ -136,6 +139,12 @@ property_notify_cb (TotemObject *totem,
 	totem_screensaver_update_from_state (totem, pi);
 }
 
+static void
+got_metadata_cb (BaconVideoWidget *bvw, TotemScreensaverPlugin *pi)
+{
+	totem_screensaver_update_from_state (pi->totem, pi);
+}
+
 static void
 lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 				      GConfEntry *entry, TotemScreensaverPlugin *pi)
@@ -151,6 +160,8 @@ impl_activate (TotemPlugin *plugin,
 	TotemScreensaverPlugin *pi = TOTEM_SCREENSAVER_PLUGIN (plugin);
 	GConfClient *gc;
 
+	pi->bvw = BACON_VIDEO_WIDGET (totem_get_video_widget (totem));
+
 	gc = gconf_client_get_default ();
 	gconf_client_add_dir (gc, GCONF_PREFIX,
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -160,9 +171,13 @@ impl_activate (TotemPlugin *plugin,
 	g_object_unref (gc);
 
 	pi->handler_id_playing = g_signal_connect (G_OBJECT (totem),
-				"notify::playing",
-				G_CALLBACK (property_notify_cb),
-				pi);
+						   "notify::playing",
+						   G_CALLBACK (property_notify_cb),
+						   pi);
+	pi->handler_id_metadata = g_signal_connect (G_OBJECT (pi->bvw),
+						    "got-metadata",
+						    G_CALLBACK (got_metadata_cb),
+						    pi);
 
 	pi->totem = g_object_ref (totem);
 
@@ -183,9 +198,17 @@ impl_deactivate	(TotemPlugin *plugin,
 	gconf_client_notify_remove (gc, pi->handler_id_gconf);
 	g_object_unref (gc);
 
-	g_signal_handler_disconnect (G_OBJECT (totem), pi->handler_id_playing);
+	if (pi->handler_id_playing != 0) {
+		g_signal_handler_disconnect (G_OBJECT (totem), pi->handler_id_playing);
+		pi->handler_id_playing = 0;
+	}
+	if (pi->handler_id_metadata != 0) {
+		g_signal_handler_disconnect (G_OBJECT (pi->bvw), pi->handler_id_metadata);
+		pi->handler_id_metadata = 0;
+	}
 
 	g_object_unref (pi->totem);
+	g_object_unref (pi->bvw);
 
 	totem_scrsaver_enable (pi->scr);
 }
