@@ -31,8 +31,7 @@
 G_BEGIN_DECLS
 
 /* Stores the state of the command line options */
-typedef struct 
-{
+typedef struct {
 	gboolean debug;
 	gboolean playpause;
 	gboolean play;
@@ -55,15 +54,16 @@ typedef struct
 	gchar **filenames;
 } TotemCmdLineOptions;
 
-extern const GOptionEntry options[];
+extern const GOptionEntry all_options[];
 extern TotemCmdLineOptions optionstate;
 
+void totem_options_register_remote_commands (Totem *totem);
 void totem_options_process_early (Totem *totem,
-	const TotemCmdLineOptions* options);
+				  const TotemCmdLineOptions* options);
 void totem_options_process_late (Totem *totem, 
-	const TotemCmdLineOptions* options);
+				 const TotemCmdLineOptions* options);
 void totem_options_process_for_server (UniqueApp *app,
-	const TotemCmdLineOptions* options);
+				       const TotemCmdLineOptions* options);
 
 G_END_DECLS
 
