@@ -47,23 +47,23 @@
 #include "debug.h"
 
 /* Callback functions for GtkBuilder */
-void checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-void checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-void checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-void connection_combobox_changed (GtkComboBox *combobox, Totem *totem);
-void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
-void visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem);
-void brightness_changed (GtkRange *range, Totem *totem);
-void contrast_changed (GtkRange *range, Totem *totem);
-void saturation_changed (GtkRange *range, Totem *totem);
-void hue_changed (GtkRange *range, Totem *totem);
-void tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem);
-void audio_out_menu_changed (GtkComboBox *combobox, Totem *totem);
-void font_set_cb (GtkFontButton * fb, Totem * totem);
-void encoding_set_cb (GtkComboBox *cb, Totem *totem);
-void font_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
-void encoding_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
+G_MODULE_EXPORT void checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void connection_combobox_changed (GtkComboBox *combobox, Totem *totem);
+G_MODULE_EXPORT void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
+G_MODULE_EXPORT void visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem);
+G_MODULE_EXPORT void brightness_changed (GtkRange *range, Totem *totem);
+G_MODULE_EXPORT void contrast_changed (GtkRange *range, Totem *totem);
+G_MODULE_EXPORT void saturation_changed (GtkRange *range, Totem *totem);
+G_MODULE_EXPORT void hue_changed (GtkRange *range, Totem *totem);
+G_MODULE_EXPORT void tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem);
+G_MODULE_EXPORT void audio_out_menu_changed (GtkComboBox *combobox, Totem *totem);
+G_MODULE_EXPORT void font_set_cb (GtkFontButton * fb, Totem * totem);
+G_MODULE_EXPORT void encoding_set_cb (GtkComboBox *cb, Totem *totem);
+G_MODULE_EXPORT void font_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
+G_MODULE_EXPORT void encoding_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
 
 static void
 totem_action_info (char *reason, Totem *totem)
@@ -265,8 +265,8 @@ lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 					      checkbutton4_toggled_cb, totem);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-				      gconf_client_get_bool (totem->gc,
-							     GCONF_PREFIX"/lock_screensaver_on_audio", NULL));
+				      !gconf_client_get_bool (totem->gc,
+							      GCONF_PREFIX"/lock_screensaver_on_audio", NULL));
 
 	g_signal_connect (item, "toggled",
 			  G_CALLBACK (checkbutton4_toggled_cb), totem);
@@ -398,7 +398,7 @@ tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem)
 void
 audio_out_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
-	BaconVideoWidgetAudioOutType audio_out;
+	BvwAudioOutType audio_out;
 	gboolean need_restart;
 
 	audio_out = gtk_combo_box_get_active (combobox);
@@ -469,13 +469,13 @@ totem_setup_preferences (Totem *totem)
 	guint i, hidden;
 	char *visual, *font, *encoding;
 	GList *list, *l;
-	BaconVideoWidgetAudioOutType audio_out;
+	BvwAudioOutType audio_out;
 	GConfValue *value;
 	GObject *item;
 
 	static struct {
 		const char *name;
-		BaconVideoWidgetVideoProperty prop;
+		BvwVideoProperty prop;
 		const char *label;
 	} props[4] = {
 		{ "tpw_contrast_scale", BVW_VIDEO_CONTRAST, "tpw_contrast_label" },
@@ -540,7 +540,7 @@ totem_setup_preferences (Totem *totem)
 	lock_screensaver_on_audio = gconf_client_get_bool (totem->gc,
 							   GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
 	item = gtk_builder_get_object (totem->xml, "tpw_screensaver_checkbutton");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), lock_screensaver_on_audio);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), !lock_screensaver_on_audio);
 	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/lock_screensaver_on_audio",
 				 (GConfClientNotifyFunc) lock_screensaver_on_audio_changed_cb,
 				 totem, NULL, NULL);
@@ -617,12 +617,12 @@ totem_setup_preferences (Totem *totem)
 	/* Brightness and all */
 	hidden = 0;
 	for (i = 0; i < G_N_ELEMENTS (props); i++) {
-		int value;
+		int prop_value;
 		item = gtk_builder_get_object (totem->xml, props[i].name);
-		value = bacon_video_widget_get_video_property (totem->bvw,
+		prop_value = bacon_video_widget_get_video_property (totem->bvw,
 							       props[i].prop);
-		if (value >= 0)
-			gtk_range_set_value (GTK_RANGE (item), (gdouble) value);
+		if (prop_value >= 0)
+			gtk_range_set_value (GTK_RANGE (item), (gdouble) prop_value);
 		else {
 			gtk_range_set_value (GTK_RANGE (item), (gdouble) 65535/2);
 			gtk_widget_hide (GTK_WIDGET (item));
