@@ -43,8 +43,6 @@ struct TotemPropertiesViewPriv {
 };
 
 static GObjectClass *parent_class = NULL;
-static void totem_properties_view_init (TotemPropertiesView *self);
-static void totem_properties_view_class_init (TotemPropertiesViewClass *class);
 static void totem_properties_view_finalize (GObject *object);
 
 G_DEFINE_TYPE (TotemPropertiesView, totem_properties_view, GTK_TYPE_TABLE)
@@ -178,7 +176,7 @@ totem_properties_view_set_location (TotemPropertiesView *props,
 		bacon_video_widget_close (props->priv->bvw);
 		bacon_video_widget_properties_reset (props->priv->props);
 
-		if (bacon_video_widget_open (props->priv->bvw, location, &error) == FALSE) {
+		if (bacon_video_widget_open (props->priv->bvw, location, NULL, &error) == FALSE) {
 			g_warning ("Couldn't open %s: %s", location, error->message);
 			g_error_free (error);
 			return;
