@@ -24,7 +24,7 @@
 #define TOTEM_URI_H
 
 #include "totem.h"
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
@@ -35,6 +35,8 @@ char *		totem_pictures_dir		(void);
 char *		totem_create_full_path		(const char *path);
 GMount *	totem_get_mount_for_media	(const char *uri);
 gboolean	totem_playing_dvd		(const char *uri);
+gboolean	totem_uri_is_subtitle		(const char *uri);
+gboolean	totem_is_special_mrl		(const char *uri);
 gboolean	totem_is_block_device		(const char *uri);
 void		totem_setup_file_monitoring	(Totem *totem);
 void		totem_setup_file_filters	(void);
